---
title: "Snippets"
description: "Reusable content snippets for documentation"
icon: "copy"
---

One of the core principles of software development is DRY (Don't Repeat
Yourself). This is a principle that apply to documentation as
well. If you find yourself repeating the same content in multiple places, you
should consider creating a custom snippet to keep your content in sync.
